@@ -1,6 +1,6 @@
 use strict; use warnings;
 package boolean;
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 my ($true, $false);
 
@@ -27,18 +27,11 @@ sub import {
 my ($true_val, $false_val, $bool_vals);
 
 BEGIN {
-    my $have_readonly = eval { require Readonly };
-
     my $t = 1;
     my $f = 0;
     $true  = do {bless \$t, 'boolean'};
     $false = do {bless \$f, 'boolean'};
 
-    if ( $have_readonly ) {
-        Readonly::Scalar($t => $t);
-        Readonly::Scalar($f => $f);
-    }
-
     $true_val  = overload::StrVal($true);
     $false_val = overload::StrVal($false);
     $bool_vals = {$true_val => 1, $false_val => 1};
@@ -66,6 +59,7 @@ sub isBoolean($) {
 }
 
 sub truth {
+    die "-truth not supported on Perl 5.22 or later" if $] >= 5.021005;
     # enable modifying true and false
     &Internals::SvREADONLY( \ !!0, 0);
     &Internals::SvREADONLY( \ !!1, 0);
